pub struct BoundedReplayStore { /* private fields */ }Expand description
Process-local TTL replay store with LRU ordering and fail-closed capacity.
Live entries are never evicted merely to make space because doing so would reopen their replay window. LRU ordering is used to remove expired entries deterministically; a full live set rejects new requests.
Implementations
Sourceimpl BoundedReplayStore
impl BoundedReplayStore
Sourcepub fn new(config: ReplayStoreConfig) -> Self
pub fn new(config: ReplayStoreConfig) -> Self
Creates an empty bounded replay store.