pub struct PeerRpcValidator { /* private fields */ }Expand description
Stateful validator for peer identity, protocol, expiry, integrity, and replay.
Implementations
Sourceimpl PeerRpcValidator
impl PeerRpcValidator
Sourcepub fn new(config: PeerRpcValidationConfig) -> Self
pub fn new(config: PeerRpcValidationConfig) -> Self
Creates a validator using the default protocol version.
Sourcepub fn with_protocol_version(self, protocol_version: ProtocolVersion) -> Self
pub fn with_protocol_version(self, protocol_version: ProtocolVersion) -> Self
Sets the protocol version accepted by this host.
Sourcepub fn with_nonce_store(self, nonce_store: Arc<dyn PeerNonceStore>) -> Self
pub fn with_nonce_store(self, nonce_store: Arc<dyn PeerNonceStore>) -> Self
Replaces process-local replay tracking with a deployment-selected store.
Sourcepub fn validate(
&self,
envelope: &PeerRpcEnvelope,
now_ms: u64,
) -> Result<(), PeerRpcError>
pub fn validate( &self, envelope: &PeerRpcEnvelope, now_ms: u64, ) -> Result<(), PeerRpcError>
Validates an envelope and records its nonce to prevent replay.